/// <reference types="node" />
import { PlatformAccessory, CharacteristicValue, CharacteristicSetCallback } from 'homebridge';
import { CasambiNetworkSession } from './casambi';
import { CasambiPlatform } from './platform';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export declare class LuminaireAccessory {
    private readonly platform;
    private readonly accessory;
    private readonly session;
    private service;
    private verticalService?;
    unitName: string;
    unitId: number;
    brightness: number;
    minCCT: number;
    maxCCT: number;
    unitChangedTimeout?: NodeJS.Timeout;
    constructor(platform: CasambiPlatform, accessory: PlatformAccessory, session: CasambiNetworkSession, unitInfo: any);
    /**
     * Handle "SET" requests from HomeKit
     * These are sent when the user changes the state of an accessory, for example, turning on a Light bulb.
     */
    setOn(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    /**
     * Handle "SET" requests from HomeKit
     * These are sent when the user changes the state of an accessory, for example, changing the Brightness
     */
    setBrightness(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    /**
     * Handle "SET" requests from HomeKit
     * These are sent when the user changes the state of an accessory, for example, changing the Brightness
     */
    setVerticalBrightness(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    /**
     * Handle "SET" requests from HomeKit
     * These are sent when the user changes the state of an accessory, for example, changing the Color Temperature
     */
    setColorTemperature(value: CharacteristicValue, callback: CharacteristicSetCallback): void;
    /**
     * Handle notifications from Casambi Cloud.
     */
    onUnitChanged(message: any): void;
    updateCharacteristicsFromUnitChanged(message: any): void;
    sendControlUnit(callback: CharacteristicSetCallback, targetControls: any): void;
}
//# sourceMappingURL=luminaire.d.ts.map